# hpyculatorPackage

![PyPI - License](https://img.shields.io/pypi/l/hpyculator)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/hpyculator)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/f276a62341d647d08cd3c3dd275097ff)](https://www.codacy.com/gh/HowieHz/hpyculatorPackage/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=HowieHz/hpyculatorPackage&amp;utm_campaign=Badge_Grade)
[![codecov](https://codecov.io/gh/HowieHz/hpyculatorPackage/branch/main/graph/badge.svg?token=TVF40RMPMA)](https://codecov.io/gh/HowieHz/hpyculatorPackage)
![PyPI - Downloads](https://img.shields.io/pypi/dm/hpyculator)
![GitHub repo size](https://img.shields.io/github/repo-size/HowieHz/hpyculatorPackage)

>基于python3.10

<https://github.com/HowieHz/hpyculator>

这个仓库是hpyculator的附属模块，如开发hpyculator插件需要此模块

此模块还包含若干子模块, 为实用工具

## 安装方法

`pip install hpyculator`

## 文档

文档<https://hpyculator.readthedocs.io/zh_CN/latest/utils_api/index.html>

## 更新日志

更新日志<https://github.com/HowieHz/hpyculator/blob/main/docs/changelog_hpyculator_module.md>
